# Auto Hierarchical Time Series Forecasting

## Installation
Few modules used in this package are not supported by python >= 3.9.* . So, we recommend you to create an virtual environment with python=3.8.* and run requirements.txt file 

Step 1 :
Create virtual environment using conda
```bash
conda create -n auto_hts python=3.8
```
Step 2 :
```bash
pip install -r requirements.txt
```
Step 3 :
```bash
pip install auto_hts_forecast
```
## Usage
